@@ -541,6 +541,21 @@ class fileviewer(object):
         except AttributeError:
             pass
         
+        try: 
+            val = data.epics.las_lambda
+            data_se['Laser Wavelength'] = "%.3f +/- %.3f nm" % (val.mean, val.std)
+            key_order_se.append('Laser Wavelength')
+        except AttributeError:
+            pass
+        
+        try: 
+            val = data.epics.las_wavenum
+            data_se['Laser Wavenumber'] = "%.5f +/- %.5f 1/cm" % (val.mean, val.std)
+            key_order_se.append('Laser Wavenumber')
+        except AttributeError:
+            pass
+        
+        
         # magnet stuff
         try: 
             val = data.epics.hh_current.mean
@@ -1367,7 +1382,7 @@ class fileviewer(object):
             
             # set up updating canvas
             fig = self.bfit.plt.gcf('inspect')
-            fig.canvas.set_window_title('Figure %d (Inspect - Updating)'%fig.number)
+            fig.canvas.manager.set_window_title('Figure %d (Inspect - Updating)'%fig.number)
             self.bfit.plt.plots['periodic'] = [fig.number]
             self.bfit.plt.active['periodic'] = self.bfit.plt.active['inspect']
             
@@ -1393,7 +1408,7 @@ class fileviewer(object):
             
             # Get the updating figure
             fig = self.bfit.plt.gcf('periodic')
-            title = fig.canvas.get_window_title()
+            title = fig.canvas.manager.get_window_title()
 
             # Check that the figure is still updating
             if 'Updating' not in title:
@@ -1447,7 +1462,7 @@ class fileviewer(object):
                 
                 # remove window
                 fig = self.bfit.plt.gcf('periodic')
-                fig.canvas.set_window_title('Figure %d (Inspect)'%fig.number)
+                fig.canvas.manager.set_window_title('Figure %d (Inspect)'%fig.number)
                 del self.bfit.plt.plots['periodic'][0]
                 self.bfit.plt.active['periodic'] = 0
             
